@@ -29,6 +29,7 @@
 #include "igraph_interface.h"
 #include "igraph_iterators.h"
 #include "igraph_memory.h"
+#include "igraph_random.h"
 #include "igraph_statusbar.h"
 #include "igraph_structural.h"
 
@@ -357,7 +358,7 @@ static void igraph_i_levc_free(igraph_vector_ptr_t *ptr) {
         igraph_vector_t *v = VECTOR(*ptr)[i];
         if (v) {
             igraph_vector_destroy(v);
-            igraph_free(v);
+            IGRAPH_FREE(VECTOR(*ptr)[i]);
         }
     }
 }
@@ -490,6 +491,7 @@ int igraph_community_leading_eigenvector(const igraph_t *graph,
     igraph_dqueue_t tosplit;
     igraph_vector_t idx, idx2, mymerges;
     igraph_vector_t strength, tmp;
+    igraph_vector_t start_vec;
     long int staken = 0;
     igraph_adjlist_t adjlist;
     igraph_inclist_t inclist;
@@ -502,9 +504,6 @@ int igraph_community_leading_eigenvector(const igraph_t *graph,
     igraph_arpack_function_t *arpcb1 =
         weights ? igraph_i_community_leading_eigenvector_weighted :
         igraph_i_community_leading_eigenvector;
-    igraph_arpack_function_t *arpcb2 =
-        weights ? igraph_i_community_leading_eigenvector2_weighted :
-        igraph_i_community_leading_eigenvector2;
     igraph_real_t sumweights = 0.0;
 
     if (weights && no_of_edges != igraph_vector_size(weights)) {
@@ -628,7 +627,6 @@ int igraph_community_leading_eigenvector(const igraph_t *graph,
     }
 
     options->ncv = 0;   /* 0 means "automatic" in igraph_arpack_rssolve */
-    options->start = 0;
     options->which[0] = 'L'; options->which[1] = 'A';
 
     /* Memory for ARPACK */
@@ -653,7 +651,6 @@ int igraph_community_leading_eigenvector(const igraph_t *graph,
         long int comm = (long int) igraph_dqueue_pop_back(&tosplit);
         /* depth first search */
         long int size = 0;
-        igraph_real_t tmpev;
 
         IGRAPH_STATUSF(("Trying to split community %li... ", 0, comm));
         IGRAPH_ALLOW_INTERRUPTION();
@@ -670,16 +667,7 @@ int igraph_community_leading_eigenvector(const igraph_t *graph,
             continue;
         }
 
-        /* We solve two eigenproblems, one for the original modularity
-           matrix, and one for the modularity matrix after deleting the
-           last row and last column from it. This is a trick to find
-           multiple leading eigenvalues, because ARPACK is sometimes
-           unstable when the first two eigenvalues are requested, but it
-           does much better for the single principal eigenvalue. */
-
-        /* We start with the smaller eigenproblem. */
-
-        options->n = (int) size - 1;
+        options->n = (int) size;
         options->info = 0;
         options->nev = 1;
         options->ldv = 0;
@@ -688,38 +676,31 @@ int igraph_community_leading_eigenvector(const igraph_t *graph,
         options->lworkl = 0;        /* we surely have enough space */
         extra.comm = comm;
 
-        /* We try calling the solver twice, once from a random starting
-           point, once from a fixed one. This is because for some hard
-           cases it tends to fail. We need to suppress error handling for
-           the first call. */
+        /* Use a random start vector, but don't let ARPACK generate the
+         * start vector -- we want to use our own RNG. Also, we want to generate
+         * values close to +1 and -1 as this is what the eigenvector should
+         * look like if there _is_ some kind of a community structure at this
+         * step to discover. Experiments showed that shuffling a vector
+         * containing equal number of slightly perturbed +/-1 values yields
+         * convergence in most cases. */
+        options->start = 1;
+        options->mxiter = options->mxiter > 10000 ? options->mxiter : 10000;  /* use more iterations, we've had convergence problems with 3000 */
+        RNG_BEGIN();
+        for (i = 0; i < options->n; i++) {
+            storage.resid[i] = (i % 2 ? 1 : -1) + RNG_UNIF(-0.1, 0.1);
+        }
+        RNG_END();
+        igraph_vector_view(&start_vec, storage.resid, options->n);
+        IGRAPH_CHECK(igraph_vector_shuffle(&start_vec));
+
         {
-            int i;
+            int retval;
             igraph_error_handler_t *errh =
                 igraph_set_error_handler(igraph_i_error_handler_none);
-            igraph_warning_handler_t *warnh =
-                igraph_set_warning_handler(igraph_warning_handler_ignore);
-            igraph_arpack_rssolve(arpcb2, &extra, options, &storage,
-                                  /*values=*/ 0, /*vectors=*/ 0);
+            retval = igraph_arpack_rssolve(arpcb1, &extra, options, &storage, /*values=*/ 0, /*vectors=*/ 0);
             igraph_set_error_handler(errh);
-            igraph_set_warning_handler(warnh);
-            if (options->nconv < 1) {
-                /* Call again from a fixed starting point. Note that we cannot use a
-                 * fixed all-1 starting vector as sometimes ARPACK would return a
-                 * 'starting vector is zero' error -- this is of course not true but
-                 * it's a result of ARPACK >= 3.6.3 trying to force the starting vector
-                 * into the range of OP (i.e. the matrix being solved). The initial
-                 * vector we use here seems to work, but I have no theoretical argument
-                 * for its usage; it just happens to work. */
-                options->start = 1;
-                options->info = 0;
-                options->ncv = 0;
-                options->lworkl = 0;    /* we surely have enough space */
-                for (i = 0; i < options->n ; i++) {
-                    storage.resid[i] = i % 2 ? 1 : -1;
-                }
-                IGRAPH_CHECK(igraph_arpack_rssolve(arpcb2, &extra, options, &storage,
-                                                   /*values=*/ 0, /*vectors=*/ 0));
-                options->start = 0;
+            if (retval != IGRAPH_SUCCESS && retval != IGRAPH_ARPACK_MAXIT && retval != IGRAPH_ARPACK_NOSHIFT) {
+                IGRAPH_ERROR("ARPACK call failed", retval);
             }
         }
 
@@ -727,46 +708,7 @@ int igraph_community_leading_eigenvector(const igraph_t *graph,
             IGRAPH_ERROR("ARPACK did not converge", IGRAPH_ARPACK_FAILED);
         }
 
-        tmpev = storage.d[0];
-
-        /* Now we do the original eigenproblem, again, twice if needed */
-
-        options->n = (int) size;
-        options->info = 0;
-        options->nev = 1;
-        options->ldv = 0;
-        options->nconv = 0;
-        options->lworkl = 0;    /* we surely have enough space */
-        options->ncv = 0;   /* 0 means "automatic" in igraph_arpack_rssolve */
-
-        {
-            int i;
-            igraph_error_handler_t *errh =
-                igraph_set_error_handler(igraph_i_error_handler_none);
-            igraph_arpack_rssolve(arpcb1, &extra, options, &storage,
-                                  /*values=*/ 0, /*vectors=*/ 0);
-            igraph_set_error_handler(errh);
-            if (options->nconv < 1) {
-                /* Call again from a fixed starting point. See the comment a few lines
-                 * above about the exact choice of this starting vector */
-                options->start = 1;
-                options->info = 0;
-                options->ncv = 0;
-                options->lworkl = 0;    /* we surely have enough space */
-                for (i = 0; i < options->n; i++) {
-                    storage.resid[i] = i % 2 ? 1 : -1;
-                }
-                IGRAPH_CHECK(igraph_arpack_rssolve(arpcb1, &extra, options, &storage,
-                                                   /*values=*/ 0, /*vectors=*/ 0));
-                options->start = 0;
-            }
-        }
-
-        if (options->nconv < 1) {
-            IGRAPH_ERROR("ARPACK did not converge", IGRAPH_ARPACK_FAILED);
-        }
-
-        /* Ok, we have the leading eigenvector of the modularity matrix*/
+        /* Ok, we have the leading eigenvector of the modularity matrix */
 
         /* ---------------------------------------------------------------*/
         /* To avoid numeric errors */
@@ -837,18 +779,6 @@ int igraph_community_leading_eigenvector(const igraph_t *graph,
             continue;
         }
 
-        /* Check for multiple leading eigenvalues */
-
-        if (fabs(storage.d[0] - tmpev) < 1e-8) {
-            IGRAPH_STATUS("multiple principal eigenvalue, no split.\n", 0);
-            if (history) {
-                IGRAPH_CHECK(igraph_vector_push_back(history,
-                                                     IGRAPH_LEVC_HIST_FAILED));
-                IGRAPH_CHECK(igraph_vector_push_back(history, comm));
-            }
-            continue;
-        }
-
         /* Count the number of vertices in each community after the split */
         l = 0;
         for (j = 0; j < size; j++) {
