@@ -374,8 +374,8 @@ int igraph_preference_game(igraph_t *graph, igraph_integer_t nodes,
  *
  * \param graph Pointer to an uninitialized graph.
  * \param nodes The number of vertices in the graph.
- * \param out_types The number of vertex out-types.
- * \param in_types The number of vertex in-types.
+ * \param no_out_types The number of vertex out-types.
+ * \param no_in_types The number of vertex in-types.
  * \param type_dist_matrix Matrix of size <code>out_types * in_types</code>,
  *   giving the joint distribution of vertex types.
  *   If \c NULL, incoming and outgoing vertex types are independent and uniformly
@@ -398,8 +398,8 @@ int igraph_preference_game(igraph_t *graph, igraph_integer_t nodes,
  */
 
 int igraph_asymmetric_preference_game(igraph_t *graph, igraph_integer_t nodes,
-                                      igraph_integer_t out_types,
-                                      igraph_integer_t in_types,
+                                      igraph_integer_t no_out_types,
+                                      igraph_integer_t no_in_types,
                                       const igraph_matrix_t *type_dist_matrix,
                                       const igraph_matrix_t *pref_matrix,
                                       igraph_vector_t *node_type_out_vec,
@@ -417,19 +417,19 @@ int igraph_asymmetric_preference_game(igraph_t *graph, igraph_integer_t nodes,
         IGRAPH_ERROR("The number of vertices must not be negative.", IGRAPH_EINVAL);
     }
 
-    if (in_types < 1) {
+    if (no_in_types < 1) {
         IGRAPH_ERROR("The number of vertex in-types must be at least 1.", IGRAPH_EINVAL);
     }
 
-    if (out_types < 1) {
+    if (no_out_types < 1) {
         IGRAPH_ERROR("The number of vertex out-types must be at least 1.", IGRAPH_EINVAL);
     }
 
     if (type_dist_matrix) {
         igraph_real_t lo;
 
-        if (igraph_matrix_nrow(type_dist_matrix) != out_types ||
-            igraph_matrix_ncol(type_dist_matrix) != in_types) {
+        if (igraph_matrix_nrow(type_dist_matrix) != no_out_types ||
+            igraph_matrix_ncol(type_dist_matrix) != no_in_types) {
             IGRAPH_ERROR("The type distribution matrix must have dimensions out_types * in_types.", IGRAPH_EINVAL);
         }
 
@@ -442,8 +442,8 @@ int igraph_asymmetric_preference_game(igraph_t *graph, igraph_integer_t nodes,
         }
     }
 
-    if (igraph_matrix_nrow(pref_matrix) != out_types ||
-        igraph_matrix_ncol(pref_matrix) != in_types) {
+    if (igraph_matrix_nrow(pref_matrix) != no_out_types ||
+        igraph_matrix_ncol(pref_matrix) != no_in_types) {
         IGRAPH_ERROR("The preference matrix must have dimensions out_types * in_types.", IGRAPH_EINVAL);
     }
 
@@ -459,7 +459,7 @@ int igraph_asymmetric_preference_game(igraph_t *graph, igraph_integer_t nodes,
         }
     }
 
-    IGRAPH_VECTOR_INIT_FINALLY(&cumdist, in_types * out_types + 1);
+    IGRAPH_VECTOR_INIT_FINALLY(&cumdist, no_in_types * no_out_types + 1);
 
     if (node_type_in_vec) {
         nodetypes_in = node_type_in_vec;
@@ -483,18 +483,18 @@ int igraph_asymmetric_preference_game(igraph_t *graph, igraph_integer_t nodes,
         IGRAPH_VECTOR_INIT_FINALLY(nodetypes_out, nodes);
     }
 
-    IGRAPH_CHECK(igraph_vector_ptr_init(&vids_by_intype, in_types));
+    IGRAPH_CHECK(igraph_vector_ptr_init(&vids_by_intype, no_in_types));
     IGRAPH_FINALLY(igraph_vector_ptr_destroy_all, &vids_by_intype);
-    IGRAPH_CHECK(igraph_vector_ptr_init(&vids_by_outtype, out_types));
+    IGRAPH_CHECK(igraph_vector_ptr_init(&vids_by_outtype, no_out_types));
     IGRAPH_FINALLY(igraph_vector_ptr_destroy_all, &vids_by_outtype);
-    for (i = 0; i < in_types; i++) {
+    for (i = 0; i < no_in_types; i++) {
         VECTOR(vids_by_intype)[i] = IGRAPH_CALLOC(1, igraph_vector_t);
         if (! VECTOR(vids_by_intype)[i]) {
             IGRAPH_ERROR("Insufficient memory for asymmetric_preference_game.", IGRAPH_ENOMEM);
         }
         IGRAPH_CHECK(igraph_vector_init(VECTOR(vids_by_intype)[i], 0));
     }
-    for (i = 0; i < out_types; i++) {
+    for (i = 0; i < no_out_types; i++) {
         VECTOR(vids_by_outtype)[i] = IGRAPH_CALLOC(1, igraph_vector_t);
         if (! VECTOR(vids_by_outtype)[i]) {
             IGRAPH_ERROR("Insufficient memory for asymmetric_preference_game.", IGRAPH_ENOMEM);
@@ -506,14 +506,16 @@ int igraph_asymmetric_preference_game(igraph_t *graph, igraph_integer_t nodes,
     IGRAPH_FINALLY(igraph_i_preference_game_free_vids_by_type, &vids_by_outtype);
 
     VECTOR(cumdist)[0] = 0;
+    k = 0;
     if (type_dist_matrix) {
-        for (i = 0, k = 0; i < out_types; i++) {
-            for (j = 0; j < in_types; j++, k++) {
+        for (j = 0; j < no_in_types; j++) {
+            for (i = 0; i < no_out_types; i++) {
                 VECTOR(cumdist)[k + 1] = VECTOR(cumdist)[k] + MATRIX(*type_dist_matrix, i, j);
+                k++;
             }
         }
     } else {
-        for (i = 0; i < out_types * in_types; i++) {
+        for (i = 0; i < no_out_types * no_in_types; i++) {
             VECTOR(cumdist)[i + 1] = i + 1;
         }
     }
@@ -522,17 +524,17 @@ int igraph_asymmetric_preference_game(igraph_t *graph, igraph_integer_t nodes,
     RNG_BEGIN();
 
     for (i = 0; i < nodes; i++) {
-        long int type1, type2;
+        long int in_type, out_type;
         igraph_real_t uni1 = RNG_UNIF(0, maxcum);
-        igraph_vector_binsearch(&cumdist, uni1, &type1);
-        type2 = (type1 - 1) % (long int) out_types;
-        type1 = (type1 - 1) / (long int) out_types;
-        VECTOR(*nodetypes_in)[i] = type1;
-        VECTOR(*nodetypes_out)[i] = type2;
+        igraph_vector_binsearch(&cumdist, uni1, &in_type);
+        out_type = (in_type - 1) % (long int) no_out_types;
+        in_type = (in_type - 1) / (long int) no_out_types;
+        VECTOR(*nodetypes_in)[i] = in_type;
+        VECTOR(*nodetypes_out)[i] = out_type;
         IGRAPH_CHECK(igraph_vector_push_back(
-                         (igraph_vector_t*)VECTOR(vids_by_intype)[type1], i));
+                         (igraph_vector_t*)VECTOR(vids_by_intype)[in_type], i));
         IGRAPH_CHECK(igraph_vector_push_back(
-                         (igraph_vector_t*)VECTOR(vids_by_outtype)[type2], i));
+                         (igraph_vector_t*)VECTOR(vids_by_outtype)[out_type], i));
     }
 
     igraph_vector_destroy(&cumdist);
@@ -541,8 +543,8 @@ int igraph_asymmetric_preference_game(igraph_t *graph, igraph_integer_t nodes,
     IGRAPH_VECTOR_INIT_FINALLY(&edges, 0);
     IGRAPH_VECTOR_INIT_FINALLY(&s, 0);
     IGRAPH_VECTOR_INIT_FINALLY(&intersect, 0);
-    for (i = 0; i < out_types; i++) {
-        for (j = 0; j < in_types; j++) {
+    for (i = 0; i < no_out_types; i++) {
+        for (j = 0; j < no_in_types; j++) {
             long int kk, l, c = 0;
             igraph_real_t p, last;
             igraph_vector_t *v1, *v2;
